@@ -12,7 +12,7 @@ def get_microsip_extra_apps(EXTRA_MODULES, is_dev= False):
     import importlib, sys
     EXTRA_APPS = []
     sic_password = os.getenv('SIC_PASSWORD')
-    print(sic_password)
+    #print(sic_password)
     from microsip_api.core.crypt import EncoderSIC
     enc = EncoderSIC()
     if not is_dev:
@@ -63,6 +63,9 @@ DJANGO_APPS = (
     'djcelery',
     'multiselectfield',
     'xhtml2pdf',
+    'debug_toolbar',
+    'django_select2',
+
 )
 
 MICROSIP_MODULES = (
@@ -149,6 +152,7 @@ try:
             for empresa in empresas_rows:                
                 try:
                     name = '%s\%s.FDB'% (carpeta_datos, empresa[0])
+                    #print(name)
                 except UnicodeDecodeError:
                     pass
                 else:
@@ -215,6 +219,7 @@ MEDIA_ROOT = os.path.join(BASE_DIR, 'media')
 # in apps' "static/" subdirectories and in STATICFILES_DIRS.
 # Example: "/home/media/media.lawrence.com/static/"
 
+print(MEDIA_ROOT)
 import socket
 s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
 try:
@@ -253,30 +258,20 @@ STATICFILES_FINDERS = (
 
 )
 
-
 # Make this unique, and don't share it with anybody.
 SECRET_KEY = '95q^soklxvniuk3(numzeb4-kbq2&h!iu1i195vj^xk2znx9ms'
 
-# CACHES = {
-#     # … default cache config and others
-#     "default": {
-#         "BACKEND": "django_redis.cache.RedisCache",
-#         "LOCATION": "redis://127.0.0.1:6379/1",
-#         "OPTIONS": {
-#             "CLIENT_CLASS": "django_redis.client.DefaultClient",
-#         }
+# SESSION_ENGINE  =  "multi_sessions.session"
+# SESSION_MULTISESSIONS_POOL  = (
+#     {
+#         "backend" : "redis_sessions.session" ,
+#         "modos" : [ "leer" , "escribir" ],
 #     },
-#     "select2": {
-#         "BACKEND": "django_redis.cache.RedisCache",
-#         "LOCATION": "redis://127.0.0.1:6379/2",
-#         "OPTIONS": {
-#             "CLIENT_CLASS": "django_redis.client.DefaultClient",
-#         }
-#     }
-# }
-
-# # Tell select2 which cache configuration to use:
-# SELECT2_CACHE_BACKEND = "select2"
+#     {
+#         "backend" : "django.contrib.sessions.backends.db" ,
+#         "modos" : [ "leer" , "eliminar" ],
+#     },
+# )
 
 MIDDLEWARE = (
     'django.middleware.security.SecurityMiddleware',
@@ -287,6 +282,7 @@ MIDDLEWARE = (
     'django.contrib.messages.middleware.MessageMiddleware',
     #'django.middleware.clickjacking.XFrameOptionsMiddleware',
     'microsip_api.comun.middleware.CustomerMiddleware',
+    'debug_toolbar.middleware.DebugToolbarMiddleware',
     # 'django.contrib.sessions.middleware.SessionMiddleware',
     # 'django.middleware.common.CommonMiddleware',
     # 'django.middleware.csrf.CsrfViewMiddleware',
@@ -390,3 +386,19 @@ EMAIL_HOST = 'smtp.gmail.com'
 EMAIL_HOST_USER = 'remitente@gmail.com'
 EMAIL_HOST_PASSWORD = 'clavedelcorreo'
 EMAIL_PORT = 587
+# SESSION_COOKIE_AGE = 600
+ 
+CACHES = {
+    "default": {
+        "BACKEND": "django_redis.cache.RedisCache",
+        "LOCATION": "redis://127.0.0.1:6379/1",
+        "OPTIONS": {"CLIENT_CLASS": "django_redis.client.DefaultClient"},
+    },
+    "select2": {
+        "BACKEND": "django_redis.cache.RedisCache",
+        "LOCATION": "redis://127.0.0.1:6379/2",
+        "OPTIONS": {"CLIENT_CLASS": "django_redis.client.DefaultClient"},
+    },
+}
+
+SELECT2_CACHE_BACKEND = "select2"
