@@ -13,14 +13,20 @@ urlpatterns = [
     path('', include('microsip_api.apps.config.urls')),
     path('administrador/', include('microsip_api.apps.administrador.urls')),
     path('autocomplete/', include('autocomplete_light.urls')),
-    # path("select2/", include("django_select2.urls")),
+    path("select2/", include("django_select2.urls")),
     # path('media/<string:path>', include('django.views.static.serve'),
     #     {'document_root': settings.MEDIA_ROOT, }),
 ]+ static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
 
+
 # static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
 for plugin in settings.EXTRA_APPS:
     urlpatterns += path(''+plugin['url_main_path'], include(plugin['app']+'.urls')),
 
-
+if settings.DEBUG:
+    import debug_toolbar
+    urlpatterns = [
+        path('__debug__/', include(debug_toolbar.urls)),
+    ] + urlpatterns
+    
 urlpatterns += staticfiles_urlpatterns()
